from django.template import Library, Node
from django.utils.safestring import mark_safe
from django.utils.html import conditional_escape

from ..filter import emojificate


register = Library()


@register.filter('emojificate', needs_autoescape=True)
def emojificate_filter(content, autoescape=True):
    "Convert any emoji in a string into accessible content."
    # return mark_safe(emojificate(content))
    if autoescape:
        esc = conditional_escape
    else:
        esc = lambda x: x
    return mark_safe(emojificate(esc(content)))


@register.tag('emojified')
def do_emojified(parser, token):
    nodelist = parser.parse(('endemojified',))
    parser.delete_first_token()
    return EmojifiedNode(nodelist)


class EmojifiedNode(Node):
    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        output = self.nodelist.render(context)
        return emojificate(output)



import unicodedata


__all__ = ['emojificate']


cdn = "https://twemoji.maxcdn.com/36x36/"
cdn_ft = ".png"


def tag(a, b):
    return "%s=\"%s\"" % (a, b)


def convert(char):
    if unicodedata.category(char) == "So":
        name = unicodedata.name(char).title()
        code = char.encode("unicode_escape").decode("utf-8")[2:].lstrip("0")
        return "".join([
            "<img",
            tag(" src", cdn + code + cdn_ft),
            tag(" alt", char),
            tag(" title", name),
            tag(" aria-label", "Emoji: %s" % name),
            ">"
        ])
    else:
        return char


def emojificate(line):
    return ''.join(convert(ch) for ch in line)
